@@ -1109,7 +1109,105 @@ class Zymkey(object):
       return sn_str.value.decode('utf-8')
    ###@}
 
+    ## @name Battery Voltage Monitor
+    ###@{
 
+   ## @brief Set battery voltage action. (model >= HSM6)
+   #  @details This function specifies the action to take when the  
+   #          battery voltage falls below the threshold set by
+   #          set_battery_voltage_threshold. If this function is never
+   #          called, do nothing is default. There are three actions:
+   #              - Do nothing
+   #              - Go to sleep until battery is replaced
+   #              - Self-destruct
+   #          With sleep and self_destruct set to False, it removes a
+   #          previously set sleep or self_destruct action.
+   #  @param sleep. Set the sleep action.
+   #  @param self_destrcut. Set the self_destruct action.
+   def set_battery_voltage_action(self, sleep=False, self_destruct=False):
+     if (not sleep and not self_destruct):
+       action = 0
+     elif (not sleep and self_destruct):
+       action = 1
+     elif (sleep and not self_destruct):
+       action = 2
+     elif (sleep and self_destruct):
+       raise AssertionError('Sleep and self-destruct cannot both be True')
+     ret = self._zkSetBatteryVoltageAction(self._zk_ctx, action)
+     if ret < 0:
+       raise AssertionError('bad return code %d' % ret)
+
+   ## @brief Sets the battery voltage threshold. (model >= HSM6)
+   #  @details This function sets the threshold at which if the
+   #           battery voltage falls bellow, the action set by
+   #           set_battery_voltage_action will be carried out. 
+   #           The recommended threshold is 2.3V. If this
+   #           function isn't called 2.5V is assumed by default.
+   #  @param threshold
+   #         The threshold in Volts.
+   def set_battery_voltage_threshold(self, threshold):
+     ret = self._zkSetBatteryVoltageThreshold(self._zk_ctx, threshold)
+     if ret < 0:
+       raise AssertionError('bad return code %d' % ret)
+
+   ###@}
+
+   ## @name HSM CPU Temperature Monitor
+   ###@{
+
+   ## @brief Set HSM CPU temperature threshold action. (model >= HSM6)
+   #  @details This function specifies the action to take when the  
+   #           HSM CPU temperature falls below the threshold set by
+   #           set_cpu_low_temp_threshold, or rises above the threshold
+   #           set by set_cpu_high_temp_threshold. There are two
+   #           actions to apply:
+   #               - Do nothing
+   #               - Self-destruct
+   #           To remove a previously set self-destruct action, call
+   #           this function with self_destruct=False.
+   #  @param self_destruct. Set the self_destruct action.
+   #  @return 0 for success, less than 0 for failure.
+   def set_cpu_temp_action(self, self_destruct=False):
+     if (self_destruct):
+       action = 1
+     else:
+       action = 0
+     ret = self._zkSetCPUTempAction(self._zk_ctx, action)
+     if ret < 0:
+       raise AssertionError('bad return code %d' % ret)
+
+
+   ## @brief Sets the HSM CPU low temperature threshold. (model >= HSM6)
+   #  @details This function sets the threshold at which if the
+   #           on-board HSM CPU's tempreature falls below, the
+   #           action set by set_cpu_temp_action will be carried out.
+   #           WARNING: You can lock yourself out in dev mode if
+   #           you set a threshold above the CPU's ambient temperature.
+   #           The recommended setting is no more than 20C.
+   #           If this function is never called, -10 degrees celsius is
+   #           assumed.
+   #  @param threshold. The threshold in celsius.
+   def set_cpu_low_temp_threshold(self, threshold):
+     ret = self._zkSetCPULowTempThreshold(self._zk_ctx, threshold)
+     if ret < 0:
+       raise AssertionError('bad return code %d' % ret)
+
+
+   ## @brief Sets the HSM CPU high temperature threshold. (model >= HSM6)
+   #  @details This function sets the threshold at which if the
+   #           on-board HSM CPU's tempreature rises above, the
+   #           action set by set_cpu_temp_action will be carried out.
+   #           WARNING: You can lock yourself out in dev mode if
+   #           you set a threshold below the CPU's ambient temperature.
+   #           The recommended setting is no less than 40C.
+   #           If this function is never called, 65 degrees celsius is
+   #           assumed.
+   #  @param threshold. The threshold in celsius.
+   def set_cpu_high_temp_threshold(self, threshold):
+     ret = self._zkSetCPUHighTempThreshold(self._zk_ctx, threshold)
+     if ret < 0:
+       raise AssertionError('bad return code %d' % ret)
+   ###@}
 
    # Interfaces to the C library
    _zkOpen = zkalib.zkOpen
@@ -1289,6 +1387,25 @@ class Zymkey(object):
       _zkSetDigitalPerimeterDetectDelays.restype = c_int
       _zkSetDigitalPerimeterDetectDelays.argtypes = [c_void_p, c_int, c_int]
 
+      _zkSetBatteryVoltageAction = zkalib.zkSetBatteryVoltageAction
+      _zkSetBatteryVoltageAction.restype = c_int
+      _zkSetBatteryVoltageAction.argtypes = [c_void_p, c_int]
+
+      _zkSetBatteryVoltageThreshold = zkalib.zkSetBatteryVoltageThreshold
+      _zkSetBatteryVoltageThreshold.restype = c_int
+      _zkSetBatteryVoltageThreshold.argtypes = [c_void_p, c_float]
+
+      _zkSetCPUTempAction = zkalib.zkSetCPUTempAction
+      _zkSetCPUTempAction.restype = c_int
+      _zkSetCPUTempAction.argtypes = [c_void_p, c_int]
+
+      _zkSetCPULowTempThreshold = zkalib.zkSetCPULowTempThreshold
+      _zkSetCPULowTempThreshold.restype = c_int
+      _zkSetCPULowTempThreshold.argtypes = [c_void_p, c_float]
+
+      _zkSetCPUHighTempThreshold = zkalib.zkSetCPUHighTempThreshold
+      _zkSetCPUHighTempThreshold.restype = c_int
+      _zkSetCPUHighTempThreshold.argtypes = [c_void_p, c_float]
    except:
       pass
 
